@@ -29,7 +29,6 @@ public:
 
 protected:
 
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   //Overrides:
   virtual void on_size_request(Gtk::Requisition* requisition);
   virtual void on_size_allocate(Gtk::Allocation& allocation);
@@ -37,8 +36,7 @@ protected:
   virtual void on_unmap();
   virtual void on_realize();
   virtual void on_unrealize();
-  virtual bool on_expose_event(GdkEventExpose* event);
-#endif /* GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED */
+  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);
 
   Glib::RefPtr<Gdk::Window> m_refGdkWindow;
 
